class Answer < ActiveRecord::Base

  # model attributes
  attr_accessible :task_id, :user_id, :status, :answer, :hints_used, :attempts

  validates_presence_of :answer, :on => :update

  # model associations
  belongs_to :task
  belongs_to :user

  # callbacks
  before_create :default_values
  after_save :update_progress

  def correct?
    self.task.solution.to_s == answer.to_s
  end

  def default_values
    self.status = 0
    self.hints_used = 0
    self.attempts = 0
    self.answer = ""
  end

  # called to avoid showing submitted answers in the task#answer rendered view
  def prep
    self.answer = ""
  end

  def use_hint(hint_no)
    if status < 2 && hints_used < hint_no+1
      self.hints_used = hints_used+1
      update_attribute(:hints_used, hints_used)
    end
  end

  # method used by the merit gem to
  # decide whether or not an user already has received points for
  # the given task
  def points?
    case self.status
      when 0
        false
      when 1
        self.status = 2
        self.save
        true
      else
        false
    end
  end

  # method used by merit to find out how
  # many points the task connected to this answer is worth.
  # called from the merit library.
  def points
    task.points
  end

  # called to ensure the skill progression associated with this task
  # is updated if the task is completed
  def update_progress
      user.update_progression(task.skill) if correct?
  end

end