class SchoolClass < ActiveRecord::Base

  # model attributes
  attr_accessible :year, :name, :student_ids, :teacher_id, :subject_ids

  validates_numericality_of :year
  validates_presence_of :name, :teacher_id
  validates_uniqueness_of :name
  validates :name, :length => {:minimum => 2}

  # model assoications
  has_many :students, :foreign_key => 'school_class_id', :class_name => 'User', :before_add => :stealing_students
  belongs_to :teacher, :class_name => 'User'
  has_and_belongs_to_many :subjects, :join_table => 'class_subjects'

  # validates that the submitted class(?) does not attempt to register students
  # already registered in other classes.
  def stealing_students(student)
    unless student.school_class.id.nil?
      errors.add(:students, :stealing_students)
      raise 'error'
    end
  end

end