class SkillProgression < ActiveRecord::Base

  # model attributes
  attr_accessible :status, :skill_id, :user_id, :progress

  validates :skill_id, uniqueness: { scope: :user_id }

  # model associations
  belongs_to :skill
  belongs_to :user

  # callbacks
  before_create :default_values
  after_update :update_parents

  def complete?
    status > 0
  end

  def points?
    case self.status
      when 0
        false
      when 1
        self.status = 2
        self.save
        true
      else
        false
    end
  end

  def default_values
    self.status = 0
    self.progress = 0
  end

  def completed_tasks
    completed = 0
    skill.tasks.each do |task|
      completed = completed+1 if user.completed_task?(task)
    end
    completed
  end

  # called whenever the progression is being updated
  def update_progress
    # counter
    completed = 0
    # if the skill has no tasks associated, then it is by definition complete
    # only if all sub-skills are complete.
    if skill.tasks.empty?
      if skill.has_children?
      skill.children.each do |sub_skill|
        completed = completed+1 if user.completed_skill?(sub_skill)
        self.progress = completed/skill.children.length.to_f
      end
      else
        self.progress = 1
      end
    else
      skill.tasks.each do |task|
        completed = completed+1 if user.completed_task?(task)
      end
      self.progress = completed/skill.tasks.length.to_f
    end
    self.status = 1 if progress == 1.0
    # call to base.save in order to save the updated progress.
    # This call will trigger 'update_parents' which will
    # update the parent progress only if the current progression is completed.
    self.save
  end

  def update_parents
    if complete? && skill.parent
      user.update_progression(skill.parent)
    end
  end


  # Returns progress as a percentage
  def get_progress
    (progress.round(2)*100).to_i
  end

end