class Subject < ActiveRecord::Base

  # model attributes
  attr_accessible :name, :skill_ids, :school_class_ids

  validates :name, presence: true, uniqueness: true

  # model associations
  has_and_belongs_to_many :school_classes, :join_table => 'class_subjects'
  has_and_belongs_to_many :skills, :after_add => :update_children

  # callback
  before_destroy {skills.clear}

  def update_children(skill)
    skill.update_children(self)
  end

  def root_skills
    root_skills = []
    skills.each do |skill|
      root_skills << skill if skill.is_root?
    end
    root_skills
  end

 end
