class Task < ActiveRecord::Base

  # model attributes
  attr_accessor :completed, :url
  attr_accessible :name, :points, :question, :solution, :hints_attributes

  # validations
  validates_presence_of :name, :points, :question, :solution
  validates_uniqueness_of :name, :scope => :skill_id
  # only accepts points in the range of 1-100 - subject to change
  validates_inclusion_of :points, :in => 1..100

  # model associations
  belongs_to :skill
  has_many :hints , :dependent => :destroy
  has_many :answers, :dependent => :destroy
  has_many :users, :through => :answers

  # callback
  after_save :update_skill_progression

  accepts_nested_attributes_for :hints, :allow_destroy => true

  def first_attempt?(user)
    # see if the answer is in the database
    answer = answers.find_by_user_id(user.id)
    user.add_progression(self.skill) unless answer
    answer
  end

  def add_answer(user)
    answers << Answer.new(:task_id => id, :user_id => user.id)
  end

  def has_hints?
    hints.length > 0
  end

  def completed?(user_id)
    answer = answers.find_by_user_id(user_id)
    begin
      if answer.correct?
        return true
      end
    rescue
      return false
    end
  end

  def update_skill_progression
    skill.update_progression
  end

end
